==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkBoxClipDataSet.java <==
// java wrapper for vtkBoxClipDataSet object
//

package vtk;
import vtk.*;

public class vtkBoxClipDataSet extends vtkUnstructuredGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBoxClip_2(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetBoxClip(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetBoxClip_2(id0,id1,id2,id3,id4,id5); }

  private native void SetGenerateClipScalars_3(int id0);
  public void SetGenerateClipScalars(int id0)
    { SetGenerateClipScalars_3(id0); }

  private native int GetGenerateClipScalars_4();
  public int GetGenerateClipScalars()
    { return GetGenerateClipScalars_4(); }

  private native void GenerateClipScalarsOn_5();
  public void GenerateClipScalarsOn()
    { GenerateClipScalarsOn_5(); }

  private native void GenerateClipScalarsOff_6();
  public void GenerateClipScalarsOff()
    { GenerateClipScalarsOff_6(); }

  private native void SetGenerateClippedOutput_7(int id0);
  public void SetGenerateClippedOutput(int id0)
    { SetGenerateClippedOutput_7(id0); }

  private native int GetGenerateClippedOutput_8();
  public int GetGenerateClippedOutput()
    { return GetGenerateClippedOutput_8(); }

  private native void GenerateClippedOutputOn_9();
  public void GenerateClippedOutputOn()
    { GenerateClippedOutputOn_9(); }

  private native void GenerateClippedOutputOff_10();
  public void GenerateClippedOutputOff()
    { GenerateClippedOutputOff_10(); }

  private native long GetClippedOutput_11();
  public vtkUnstructuredGrid GetClippedOutput() {
    long temp = GetClippedOutput_11();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfOutputs_12();
  public int GetNumberOfOutputs()
    { return GetNumberOfOutputs_12(); }

  private native void SetLocator_13(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_13(id0); }

  private native long GetLocator_14();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_14();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_15();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_15(); }

  private native int GetMTime_16();
  public int GetMTime()
    { return GetMTime_16(); }

  private native int GetOrientation_17();
  public int GetOrientation()
    { return GetOrientation_17(); }

  private native void SetOrientation_18(int id0);
  public void SetOrientation(int id0)
    { SetOrientation_18(id0); }

  private native void InterpolateEdge_19(vtkDataSetAttributes id0,int id1,int id2,int id3,double id4);
  public void InterpolateEdge(vtkDataSetAttributes id0,int id1,int id2,int id3,double id4)
    { InterpolateEdge_19(id0,id1,id2,id3,id4); }

  private native void ClipBox_20(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipBox(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipBox_20(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipHexahedron_21(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipHexahedron(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipHexahedron_21(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipBox2D_22(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipBox2D(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipBox2D_22(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipHexahedron2D_23(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipHexahedron2D(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipHexahedron2D_23(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipBox1D_24(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipBox1D(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipBox1D_24(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipHexahedron1D_25(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipHexahedron1D(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipHexahedron1D_25(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipBox0D_26(vtkGenericCell id0,vtkIncrementalPointLocator id1,vtkCellArray id2,vtkPointData id3,vtkPointData id4,vtkCellData id5,int id6,vtkCellData id7);
  public void ClipBox0D(vtkGenericCell id0,vtkIncrementalPointLocator id1,vtkCellArray id2,vtkPointData id3,vtkPointData id4,vtkCellData id5,int id6,vtkCellData id7)
    { ClipBox0D_26(id0,id1,id2,id3,id4,id5,id6,id7); }

  private native void ClipHexahedron0D_27(vtkGenericCell id0,vtkIncrementalPointLocator id1,vtkCellArray id2,vtkPointData id3,vtkPointData id4,vtkCellData id5,int id6,vtkCellData id7);
  public void ClipHexahedron0D(vtkGenericCell id0,vtkIncrementalPointLocator id1,vtkCellArray id2,vtkPointData id3,vtkPointData id4,vtkCellData id5,int id6,vtkCellData id7)
    { ClipHexahedron0D_27(id0,id1,id2,id3,id4,id5,id6,id7); }

  public vtkBoxClipDataSet() { super(); }

  public vtkBoxClipDataSet(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkBoxClipDataSet.java <==
// java wrapper for vtkBoxClipDataSet object
//

package vtk;
import vtk.*;

public class vtkBoxClipDataSet extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBoxClip_2(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetBoxClip(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetBoxClip_2(id0,id1,id2,id3,id4,id5); }

  private native void SetGenerateClipScalars_3(int id0);
  public void SetGenerateClipScalars(int id0)
    { SetGenerateClipScalars_3(id0); }

  private native int GetGenerateClipScalars_4();
  public int GetGenerateClipScalars()
    { return GetGenerateClipScalars_4(); }

  private native void GenerateClipScalarsOn_5();
  public void GenerateClipScalarsOn()
    { GenerateClipScalarsOn_5(); }

  private native void GenerateClipScalarsOff_6();
  public void GenerateClipScalarsOff()
    { GenerateClipScalarsOff_6(); }

  private native void SetGenerateClippedOutput_7(int id0);
  public void SetGenerateClippedOutput(int id0)
    { SetGenerateClippedOutput_7(id0); }

  private native int GetGenerateClippedOutput_8();
  public int GetGenerateClippedOutput()
    { return GetGenerateClippedOutput_8(); }

  private native void GenerateClippedOutputOn_9();
  public void GenerateClippedOutputOn()
    { GenerateClippedOutputOn_9(); }

  private native void GenerateClippedOutputOff_10();
  public void GenerateClippedOutputOff()
    { GenerateClippedOutputOff_10(); }

  private native long GetClippedOutput_11();
  public vtkUnstructuredGrid GetClippedOutput() {
    long temp = GetClippedOutput_11();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfOutputs_12();
  public int GetNumberOfOutputs()
    { return GetNumberOfOutputs_12(); }

  private native void SetLocator_13(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_13(id0); }

  private native long GetLocator_14();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_14();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_15();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_15(); }

  private native int GetMTime_16();
  public int GetMTime()
    { return GetMTime_16(); }

  private native int GetOrientation_17();
  public int GetOrientation()
    { return GetOrientation_17(); }

  private native void SetOrientation_18(int id0);
  public void SetOrientation(int id0)
    { SetOrientation_18(id0); }

  private native void InterpolateEdge_19(vtkDataSetAttributes id0,int id1,int id2,int id3,double id4);
  public void InterpolateEdge(vtkDataSetAttributes id0,int id1,int id2,int id3,double id4)
    { InterpolateEdge_19(id0,id1,id2,id3,id4); }

  private native void ClipBox_20(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipBox(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipBox_20(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipHexahedron_21(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipHexahedron(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipHexahedron_21(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipBox2D_22(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipBox2D(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipBox2D_22(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipHexahedron2D_23(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipHexahedron2D(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipHexahedron2D_23(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipBox1D_24(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipBox1D(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipBox1D_24(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipHexahedron1D_25(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8);
  public void ClipHexahedron1D(vtkPoints id0,vtkGenericCell id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8)
    { ClipHexahedron1D_25(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void ClipBox0D_26(vtkGenericCell id0,vtkIncrementalPointLocator id1,vtkCellArray id2,vtkPointData id3,vtkPointData id4,vtkCellData id5,int id6,vtkCellData id7);
  public void ClipBox0D(vtkGenericCell id0,vtkIncrementalPointLocator id1,vtkCellArray id2,vtkPointData id3,vtkPointData id4,vtkCellData id5,int id6,vtkCellData id7)
    { ClipBox0D_26(id0,id1,id2,id3,id4,id5,id6,id7); }

  private native void ClipHexahedron0D_27(vtkGenericCell id0,vtkIncrementalPointLocator id1,vtkCellArray id2,vtkPointData id3,vtkPointData id4,vtkCellData id5,int id6,vtkCellData id7);
  public void ClipHexahedron0D(vtkGenericCell id0,vtkIncrementalPointLocator id1,vtkCellArray id2,vtkPointData id3,vtkPointData id4,vtkCellData id5,int id6,vtkCellData id7)
    { ClipHexahedron0D_27(id0,id1,id2,id3,id4,id5,id6,id7); }

  public vtkBoxClipDataSet() { super(); }

  public vtkBoxClipDataSet(long id) { super(id); }
  public native long   VTKInit();

}
